=======
Instant
=======

.. attention::
   Instant has been retired after 2017.2.0 release. It is no longer
   needed in FEniCS and hence no longer maintained and tested. All
   test systems status information may be misleading.

Instant is a Python module that allows for instant inlining of C and
C++ code in Python. It is a small Python module built on top of SWIG
and Distutils.

Instant is part of the FEniCS Project.

For more information, visit http://www.fenicsproject.org.


Documentation
=============

Documentation can be viewed at http://fenics-instant.readthedocs.org/.

.. image:: https://readthedocs.org/projects/fenics-instant/badge/?version=latest
   :target: http://fenics.readthedocs.io/projects/instant/en/latest/?badge=latest
   :alt: Documentation Status


Automated Testing
=================

We use Bitbucket Pipelines and Atlassian Bamboo to perform automated
testing.

.. image:: https://bitbucket-badges.useast.atlassian.io/badge/fenics-project/instant.svg
   :target: https://bitbucket.org/fenics-project/instant/addon/pipelines/home
   :alt: Pipelines Build Status

.. image:: http://fenics-bamboo.simula.no:8085/plugins/servlet/wittified/build-status/IN-ID
   :target: http://fenics-bamboo.simula.no:8085/browse/IN-ID/latest
   :alt: Bamboo Build Status


Code Coverage
=============

Code coverage reports can be viewed at
https://coveralls.io/bitbucket/fenics-project/instant.

.. image:: https://coveralls.io/repos/bitbucket/fenics-project/instant/badge.svg?branch=master
   :target: https://coveralls.io/bitbucket/fenics-project/instant?branch=master
   :alt: Coverage Status


License
=======

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.
